AhapKeys class

Constructors

AhapKeys()

Properties

event → String
final
eventDuration → String
final
eventParameters → String
final
eventType → String
final
hapticContinuous → String
final
hapticIntensity → String
final
hapticIntensityControl → String
final
hapticSharpness → String
final
hapticSharpnessControl → String
final
hashCode → int
The hash code for this object.
no setterinherited
parameter → String
final
parameterCurve → String
final
parameterCurveControlPoints → String
final
parameterId → String
final
parameterValue → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited