AhapEvent class

Constructors

AhapEvent({required double time, required double duration, required double sharpness, required double intensity, AhapEventType type = AhapEventType.hapticEvent, AhapParameterType? parameterType})

Properties

duration → double
final
hashCode → int
The hash code for this object.
no setterinherited
intensity → double
final
parameterType → AhapParameterType?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharpness → double
final
time → double
final
type → AhapEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic> map) → List<AhapEvent>
Converts a map to an AhapEvent